@@ -5,24 +5,31 @@ from django.contrib.auth.decorators import login_required
 from django.contrib.auth.models import User
 from django.contrib.contenttypes.models import ContentType
 
-from actstream.models import Follow, Action, user_stream, actor_stream, model_stream
+from actstream.models import Follow, Action, user_stream, actor_stream, \
+    model_stream, follow, unfollow
+
+def respond(request, code):
+    """
+    Responds to the request with the given response code.
+    If ``next`` is in the form, it will redirect instead
+    """
+    if 'next' in request.REQUEST:
+        return HttpResponseRedirect(request.REQUEST['next'])
+    return type('Response%d' % code, (HttpResponse,), {'status_code': code})()
 
 @login_required
-def follow(request, content_type_id, object_id):
+def follow_unfollow(request, content_type_id, object_id, do_follow=True):
     """
-    Creates follow relationship st ``request.user`` starts following the actor defined by ``content_type_id``, ``object_id``
+    Creates or deletes the follow relationship between ``request.user`` and the actor defined by ``content_type_id``, ``object_id``
     """
     ctype = get_object_or_404(ContentType, pk=content_type_id)
     actor = get_object_or_404(ctype.model_class(), pk=object_id)
-    _,created = Follow.objects.get_or_create(user=request.user,
-        content_type=ctype, object_id=object_id)
-    if request.is_ajax():
-        return HttpResponse()
-    if 'next' in request.REQUEST:
-        return HttpResponseRedirect(request.REQUEST['next'])
-    return render_to_response('activity/follow.html', {
-        'actor':actor, 'created':created
-    }, context_instance=RequestContext(request))
+        
+    if do_follow:
+        follow(request.user, actor)
+        return respond(request, 201) # CREATED
+    unfollow(request.user, actor)
+    return respond(request, 204) # NO CONTENT
     
 @login_required
 def stream(request):
@@ -42,14 +49,14 @@ def followers(request, content_type_id, object_id):
     follows = Follow.objects.filter(content_type=ctype, object_id=object_id)
     actor = get_object_or_404(ctype.model_class(), pk=object_id)
     return render_to_response('activity/followers.html', {
-        'followers': [f.user for f in follows], 'actor':actor
+        'followers': (f.user for f in follows), 'actor':actor
     }, context_instance=RequestContext(request))
     
 def user(request, username):
     """
     ``User`` focused activity stream. (Eg: Profile page twitter.com/justquick)
     """
-    user = get_object_or_404(User, username=username)
+    user = get_object_or_404(User, username=username, is_active=True)
     return render_to_response('activity/actor.html', {
         'ctype': ContentType.objects.get_for_model(User),
         'actor':user,'action_list':actor_stream(user)
@@ -67,6 +74,7 @@ def actor(request, content_type_id, object_id):
     """
     ``Actor`` focused activity stream for actor defined by ``content_type_id``, ``object_id``
     """
+    1/0
     ctype = get_object_or_404(ContentType, pk=content_type_id)
     actor = get_object_or_404(ctype.model_class(), pk=object_id)    
     return render_to_response('activity/actor.html', {
